@@ -4,8 +4,6 @@ from django.forms.util import flatatt
 from django.utils import safestring
 from django.template.loader import render_to_string
 
-from .channel import *
-
 __all__ = ['AutocompleteWidget']
 
 
@@ -23,11 +21,15 @@ class AutocompleteWidget(forms.SelectMultiple):
 
         class AuthorsForm(forms.Form):
             lead_author = forms.ModelChoiceField(Author.objects.all(), widget=
-                autocomplete_light.AutocompleteWidget('AuthorChannel', max_items=1))
-            contributors = forms.ModelMultipleChoiceField(Author.objects.all(), widget=
-                autocomplete_light.AutocompleteWidget('AuthorChannel'))
+                autocomplete_light.AutocompleteWidget(
+                    'AuthorChannel', max_items=1))
+
+            contributors = forms.ModelMultipleChoiceField(Author.objects.all(),
+                widget=autocomplete_light.AutocompleteWidget('AuthorChannel'))
     """
 
+    payload = {}
+
     def __init__(self, channel_name, *args, **kwargs):
         """
         AutocompleteWidget constructor decorates SelectMultiple constructor
@@ -63,15 +65,21 @@ class AutocompleteWidget(forms.SelectMultiple):
             default, its value is copied from channel.bootstrap.
 
         placeholder
-            The initial value of the autocomplete input field. It can be something
-            like 'type your search here'. By default, it is copied from
-            channel.placeholder.
+            The initial value of the autocomplete input field. It can be
+            something like 'type your search here'. By default, it is copied
+            from channel.placeholder.
+
+        payload
+            A dict of data that will be exported to JSON, and parsed into the
+            Deck instance in javascript. It allows to pass variables from
+            Python to Javascript.
         """
         self.channel_name = channel_name
 
         from autocomplete_light import registry
         self.channel = registry[channel_name]()
 
+        self.payload.update(kwargs.pop('payload', {}))
         self.max_items = kwargs.pop('max_items', 0)
         self.min_characters = kwargs.pop('min_characters', 0)
         self.bootstrap = kwargs.pop('bootstrap', self.channel.bootstrap)
@@ -101,10 +109,15 @@ class AutocompleteWidget(forms.SelectMultiple):
             values = value
 
         if values and not self.channel.are_valid(values):
-            raise forms.ValidationError('%s cannot find pk(s) %s' % (self.channel_name, values))
+            raise forms.ValidationError('%s cannot validate %s' % (
+                self.channel_name, values))
 
+        self.payload.update(self.as_dict())
+        self.payload['channel'] = self.channel.as_dict()
+
+        channel_name = self.channel_name.lower()
         return safestring.mark_safe(render_to_string([
-                'autocomplete_light/%s/widget.html' % self.channel_name.lower(),
+                'autocomplete_light/%s/widget.html' % channel_name,
                 'autocomplete_light/widget.html',
             ], {
                 'widget': self,
@@ -112,13 +125,21 @@ class AutocompleteWidget(forms.SelectMultiple):
                 'values': values,
                 'channel': self.channel,
                 'results': self.channel.get_results(values or []),
-                'json_value': safestring.mark_safe(simplejson.dumps(value)),
-                'json_channel': safestring.mark_safe(simplejson.dumps(
-                    self.channel.as_dict())),
+                'json_payload': safestring.mark_safe(simplejson.dumps(
+                    self.payload)),
                 'extra_attrs': safestring.mark_safe(flatatt(final_attrs)),
             }
         ))
 
+    def as_dict(self):
+        return {
+            'max_items': self.max_items,
+            'min_characters': self.min_characters,
+            'bootstrap': self.bootstrap,
+            # cast to unicode as it might be a gettext proxy
+            'placeholder': unicode(self.placeholder),
+        }
+
     # we might want to split up in two widgets for that ... is it necessary ?
     # apparently not yet, but maybe at next django release
     def value_from_datadict(self, data, files, name):
@@ -126,7 +147,8 @@ class AutocompleteWidget(forms.SelectMultiple):
         if self.max_items == 1:
             return forms.Select.value_from_datadict(self, data, files, name)
         else:
-            return forms.SelectMultiple.value_from_datadict(self, data, files, name)
+            return forms.SelectMultiple.value_from_datadict(self, data, files,
+                name)
 
     def _has_changed(self, initial, data):
         """Route to Select if max_items is 1, else route to SelectMultiple"""
